==> xlniux-client-1.0.1-20141016.100933-1-sources.jar: com/xunlei/niux/client/jinzuan/SignInClient.java <==
package com.xunlei.niux.client.jinzuan;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import com.google.gson.reflect.TypeToken;
import com.xunlei.channel.util.Md5Encrypt;
import com.xunlei.niux.client.util.HttpClientUtil;
import com.xunlei.niux.client.util.MapEasyUtils;
import com.xunlei.niux.client.util.SignUtil;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

import java.lang.reflect.Type;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.ResourceBundle;

/**
 * Created by jamesjxin on 14-3-13.
 */
public class SignInClient {
    private static final Logger logger = Logger.getLogger(SignInClient.class);
    private final static String SignInUrl = "http://jinzuan.niu.xunlei.com:9090/sign/";
    private final static String priKey = ResourceBundle.getBundle("niuxclient").getString("SignInClient_priKey");


    public static String doSign(String userId, String ip) {
        String url = SignInUrl + "dosign.do?";
        Map<String, String> param = new HashMap<String, String>();
        String timestamp = String.valueOf(new Date().getTime());
        url += "uid="+userId;
        url += "&timestamp=" + timestamp;
        url += "&ip="+ip;

        String sign = Md5Encrypt.md5(userId+timestamp+ip+priKey);

        url += "&sign="+sign;
//        param.put("uid", userId);
//        param.put("timestamp", String.valueOf(new Date().getTime()));
//        param.put("ip", ip);



//        String sign = SignUtil.sign(param, Key);
//        param.put("sign",sign);
//        String paramStr = SignUtil.getSignatureContent(param);

//        url += paramStr;

        logger.info("doSign request URL: "+url);
        String resp = HttpClientUtil.get(url);
        logger.info("doSign request response: "+resp);
        return resp;
    }


}

==> xlniux-client-1.0.4-20141021.084728-3-sources.jar: com/xunlei/niux/client/jinzuan/SignInClient.java <==
package com.xunlei.niux.client.jinzuan;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import com.google.gson.reflect.TypeToken;
import com.xunlei.channel.util.Md5Encrypt;
import com.xunlei.niux.client.util.HttpClientUtil;
import com.xunlei.niux.client.util.MapEasyUtils;
import com.xunlei.niux.client.util.SignUtil;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

import java.lang.reflect.Type;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.ResourceBundle;

/**
 * Created by jamesjxin on 14-3-13.
 */
public class SignInClient {
    private static final Logger logger = Logger.getLogger(SignInClient.class);
    private final static String SignInUrl = "http://jinzuan.niu.xunlei.com:9090/sign/";
    private final static String priKey = ResourceBundle.getBundle("niuxclient").getString("SignInClient_priKey");


    public static String doSign(String userId, String ip, String day) {
        String url = SignInUrl + "dosign.do?";
        Map<String, String> param = new HashMap<String, String>();
        String timestamp = String.valueOf(new Date().getTime());
        url += "uid="+userId;
        url += "&timestamp=" + timestamp;
        url += "&day=" + day;
        url += "&ip="+ip;

        String sign = Md5Encrypt.md5(userId+timestamp+day+ip+priKey);

        url += "&sign="+sign;
//        param.put("uid", userId);
//        param.put("timestamp", String.valueOf(new Date().getTime()));
//        param.put("ip", ip);



//        String sign = SignUtil.sign(param, Key);
//        param.put("sign",sign);
//        String paramStr = SignUtil.getSignatureContent(param);

//        url += paramStr;

        logger.info("doSign request URL: "+url);
        String resp = HttpClientUtil.get(url);
        logger.info("doSign request response: "+resp);
        return resp;
    }


}
